==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-panel/plugin-volume/volume_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="62"/>
        <source>Increase sound volume</source>
        <translation>Augmenter le volume du son</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="68"/>
        <source>Decrease sound volume</source>
        <translation>Diminuer le volume du son</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="74"/>
        <source>Mute/unmute sound volume</source>
        <translation>Son muet ou pas</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="135"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Contrôle du volume : le raccourci suivant&apos; ne peut pas être défini &apos;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="223"/>
        <location filename="../../../lxqtvolume.cpp" line="233"/>
        <source>Volume: %1</source>
        <translation>Volume : %1</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Paramètres du contrôle de volume</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Périphérique à contrôler</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="28"/>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Muet avec le clic central</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Afficher avec un clic de souris</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Permet le volume jusqu&apos;à 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="92"/>
        <source>Volume adjust step</source>
        <translation>Pas du réglage du volume</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="111"/>
        <source>External Mixer</source>
        <translation>Mixer externe</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../../../volumepopup.cpp" line="53"/>
        <source>Launch mixer</source>
        <translation>Démarre le mixer</translation>
    </message>
    <message>
        <location filename="../../../volumepopup.cpp" line="54"/>
        <source>Mi&amp;xer</source>
        <translation>Mi&amp;xeur</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-volume/volume_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="63"/>
        <source>Increase sound volume</source>
        <translation>Augmenter le volume du son</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="69"/>
        <source>Decrease sound volume</source>
        <translation>Diminuer le volume du son</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="75"/>
        <source>Mute/unmute sound volume</source>
        <translation>Son muet ou pas</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="136"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Contrôle du volume : le raccourci suivant&apos; ne peut pas être défini &apos;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="287"/>
        <source>Volume: muted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolume.cpp" line="289"/>
        <source>Volume: %1</source>
        <translation>Volume : %1</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Paramètres du contrôle de volume</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Périphérique à contrôler</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="28"/>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Muet avec le clic central</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Afficher avec un clic de souris</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Permet le volume jusqu&apos;à 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>Pas du réglage du volume</translation>
    </message>
    <message>
        <location filename="../../../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>Mixer externe</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../../../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>Démarre le mixer</translation>
    </message>
    <message>
        <location filename="../../../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>Mi&amp;xeur</translation>
    </message>
</context>
</TS>
